/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "image.h"

void imageInit(image_t *image, texture_t *texture) {
  image->x = 0;
  image->y = 0;
  image->quad.verticeCount = -1;
  imageSetTexture(image, texture);
}

void imageSetTexture(image_t *image, texture_t *texture) {
  if(image->quad.verticeCount != -1) {
    primitiveDispose(&image->quad);
    image->quad.verticeCount = -1;
  }
  
  image->texture = texture;
  quadInit(&image->quad, 0, 0,0,0,0, texture->width,texture->height,1,1);
}

void imageRender(image_t *image, shader_t *shader) {
  shaderUsePosition(shader, image->x, image->y, 0, 0, 0, 0);
  primitiveDraw(&image->quad, 0, -1);
}

void imageDispose(image_t *image) {
  if(image->quad.verticeCount != -1) primitiveDispose(&image->quad);
}